==> platform-client-v2-40.0.0-sources.jar: com/mypurecloud/sdk/v2/model/SMSAvailablePhoneNumberEntityListing.java <==
package com.mypurecloud.sdk.v2.model;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.mypurecloud.sdk.v2.model.SmsAvailablePhoneNumber;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.util.ArrayList;
import java.util.List;

import java.io.Serializable;
/**
 * SMSAvailablePhoneNumberEntityListing
 */

public class SMSAvailablePhoneNumberEntityListing  implements Serializable {
  
  private List<SmsAvailablePhoneNumber> entities = new ArrayList<SmsAvailablePhoneNumber>();

  
  /**
   **/
  public SMSAvailablePhoneNumberEntityListing entities(List<SmsAvailablePhoneNumber> entities) {
    this.entities = entities;
    return this;
  }
  
  @ApiModelProperty(example = "null", value = "")
  @JsonProperty("entities")
  public List<SmsAvailablePhoneNumber> getEntities() {
    return entities;
  }
  public void setEntities(List<SmsAvailablePhoneNumber> entities) {
    this.entities = entities;
  }

  

  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    SMSAvailablePhoneNumberEntityListing sMSAvailablePhoneNumberEntityListing = (SMSAvailablePhoneNumberEntityListing) o;
    return Objects.equals(this.entities, sMSAvailablePhoneNumberEntityListing.entities);
  }

  @Override
  public int hashCode() {
    return Objects.hash(entities);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class SMSAvailablePhoneNumberEntityListing {\n");
    
    sb.append("    entities: ").append(toIndentedString(entities)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}

==> platform-client-v2-203.0.0-sources.jar: com/mypurecloud/sdk/v2/model/SMSAvailablePhoneNumberEntityListing.java <==
package com.mypurecloud.sdk.v2.model;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import com.fasterxml.jackson.core.JsonParser;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import com.fasterxml.jackson.databind.deser.std.StdDeserializer;
import java.util.Objects;
import java.util.ArrayList;
import java.io.IOException;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.mypurecloud.sdk.v2.model.SmsAvailablePhoneNumber;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.util.ArrayList;
import java.util.List;

import java.io.Serializable;
/**
 * SMSAvailablePhoneNumberEntityListing
 */

public class SMSAvailablePhoneNumberEntityListing  implements Serializable {
  
  private List<SmsAvailablePhoneNumber> entities = new ArrayList<SmsAvailablePhoneNumber>();

  
  /**
   **/
  public SMSAvailablePhoneNumberEntityListing entities(List<SmsAvailablePhoneNumber> entities) {
    this.entities = entities;
    return this;
  }
  
  @ApiModelProperty(example = "null", value = "")
  @JsonProperty("entities")
  public List<SmsAvailablePhoneNumber> getEntities() {
    return entities;
  }
  public void setEntities(List<SmsAvailablePhoneNumber> entities) {
    this.entities = entities;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    SMSAvailablePhoneNumberEntityListing sMSAvailablePhoneNumberEntityListing = (SMSAvailablePhoneNumberEntityListing) o;

    return Objects.equals(this.entities, sMSAvailablePhoneNumberEntityListing.entities);
  }

  @Override
  public int hashCode() {
    return Objects.hash(entities);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class SMSAvailablePhoneNumberEntityListing {\n");
    
    sb.append("    entities: ").append(toIndentedString(entities)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
